==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/wb/profile/profileUtils.js <==
function _toConsumableArray(r) { return _arrayWithoutHoles(r) || _iterableToArray(r) || _unsupportedIterableToArray(r) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _iterableToArray(r) { if ("undefined" != typeof Symbol && null != r[Symbol.iterator] || null != r["@@iterator"]) return Array.from(r); }
function _arrayWithoutHoles(r) { if (Array.isArray(r)) return _arrayLikeToArray(r); }
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * @copyright 2019 Tridium, Inc. All Rights Reserved.
 * @author Logan Byam
 */

/* eslint-env browser */

define(['baja!', 'jquery', 'Promise', 'underscore', 'nmodule/js/rc/asyncUtils/asyncUtils', 'nmodule/webEditors/rc/transform/ExportCommand'], function (baja, $, Promise, _, asyncUtils, ExportCommand) {
  'use strict';

  /**
   * API Status: **Private**
   * @exports nmodule/webEditors/rc/wb/profile/profileUtils
   */
  var exports = {};
  var doRequire = asyncUtils.doRequire;

  /**
   * @returns {baja.Ord} the ORD currently being viewed in the profile. This ORD
   * will correspond to the current ORD in Workbench, even if used in the
   * browser (i.e. it may contain `fox:` or similar schemes). Call
   * `.relativizeToSession()` if needed.
   */
  exports.getCurrentOrd = function () {
    return exports.uriToOrd(location.href);
  };

  /**
   * If there is a view query, get the ord without it.
   * @param {baja.Ord} [ord] if the ord is not present, the `getCurrentOrd()` will be used.
   * @returns {baja.Ord} the ORD without the View Query
   */
  exports.getOrdWithoutViewQuery = function (ord) {
    var ordStr = getOrdStrFromParam(ord);
    var viewIndex = getViewIndex(ordStr);
    if (viewIndex > -1) {
      return baja.Ord.make(ordStr.substring(0, viewIndex - 1));
    }
    return baja.Ord.make(ordStr);
  };

  /**
   * @param {string|undefined} uri
   * @param {object} [params]
   * @param {string} [params.host] specify the desired host in the generated
   * ORD. If omitted, will be parsed out of the URI, or omitted if the URI is
   * relative.
   * @param {number} [params.port] specify the desired port in the generated
   * ORD.
   * @param {string} [params.protocol] specify the desired protocol in the
   * generated ORD. If omitted, will be `fox` for an `http` URI, `foxs` for an
   * `https` URI, or omitted if the URI is relative.
   * @returns {baja.Ord} an ORD parsed from the given URI. Will be
   * `baja.Ord.DEFAULT` if the URI did not match the expected format or if the URI is falsy.
   */
  exports.uriToOrd = function (uri) {
    var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    if (!uri) {
      return baja.Ord.DEFAULT;
    }
    var match = uri.match(/^(https?)?(:\/\/)?([^:/]+)?(:(\d+))?(\/ord[/?])(.*)$/);
    if (!match) {
      return baja.Ord.DEFAULT;
    }
    var _match = _slicedToArray(match, 8),
      protocol = _match[1],
      host = _match[3],
      port = _match[5],
      ord = _match[7];
    var path = decodeURIComponent(ord);
    host = params.host || host;
    port = params.port || port;
    if (host) {
      var targetProtocol = params.protocol || (protocol === 'https' ? 'foxs' : 'fox');
      if (port) {
        host = host + ':' + port;
      }
      return baja.Ord.make("ip:".concat(host, "|").concat(targetProtocol, ":|").concat(path));
    } else {
      return baja.Ord.make(path);
    }
  };

  /**
   *
   * @param {module:bajaux/Widget} widget
   * @returns {Promise.<Array.<module:bajaux/commands/Command>>}
   */
  exports.resolveProfileCommands = function (widget) {
    return resolveMediaCommands(widget).then(function (mediaCommands) {
      return [].concat(_toConsumableArray(mediaCommands), [new ExportCommand(widget)]);
    });
  };

  /**
   * Resolve to the current View item if it is available.
   * @return {Promise.<module:profileInfo~ViewInfo|undefined>}
   */
  exports.resolveCurrentViewItem = function () {
    return exports.$resolveViewInfo().then(function (viewInfo) {
      if (viewInfo) {
        var list = viewInfo.list;
        return _.findWhere(list, {
          def: true
        }) || _.first(list);
      }
    });
  };

  /**
   * Return the current ViewId. This information is available from `hx`
   * even if the 'profileInfo' is not defined.
   * @return {Promise.<String|undefined>}
   */
  exports.resolveCurrentViewId = function () {
    return exports.resolveCurrentViewItem().then(function (viewItem) {
      if (viewItem) {
        var viewQuery = exports.getViewQuery(baja.Ord.make(viewItem.ord));
        if (viewQuery) {
          return viewQuery.getViewId();
        }
      }
      var hx = window.hx;
      if (hx && _.isFunction(hx.getProfileInfo)) {
        var profileInfo = hx.getProfileInfo();
        return profileInfo && profileInfo.viewId;
      }
    });
  };

  /**
   * Get the ViewQuery for an ord.
   * @param {baja.Ord} [ord] if the ord is not present, the `getCurrentOrd()` will be used.
   * @return {baja.ViewQuery|undefined}
   */
  exports.getViewQuery = function (ord) {
    var ordStr = getOrdStrFromParam(ord),
      viewIndex = getViewIndex(ordStr);
    if (viewIndex > -1) {
      var viewQueryBody = ordStr.substring(viewIndex + 5);
      return new baja.ViewQuery(viewQueryBody);
    }
  };

  /**
   * Get a View Parameter from the current `window.location.href`
   * @param {String} name
   * @return {String|undefined}
   */
  exports.getViewParameter = function (name) {
    var viewQuery = exports.getViewQuery();
    if (viewQuery) {
      var params = viewQuery.getParameters();
      return params[name];
    }
  };

  /**
   * Get the custom message provided by jetty from JQuery error handler
   * @param {JQuery.jqXHR} jqXHR
   * @param {String} textStatus
   * @param {errorThrown} errorThrown
   * @return {Error}
   */
  exports.getServletError = function (jqXHR, textStatus, errorThrown) {
    var responseText = jqXHR.responseText;
    //jetty provides HTML to get to local error message so we must generate an HTML page and parse it from there.
    var message = $(responseText).find('tr:nth-child(3) td').text();
    if (!message && errorThrown) {
      message = String(errorThrown);
    }
    if (!message) {
      message = textStatus;
    }
    return new Error(message);
  };

  /**
   * Get the browser's `window.location.href`.
   * @private
   * @return {String}
   */
  exports.$getLocation = function () {
    return window.location.href;
  };

  /**
   * If `profileInfo` is not defined, this will resolve to an `undefined` value,
   * This will happen for profile's other than the Html5HxProfile and it will
   * happen within the Html5HxProfile when the page was loaded as a popup.
   * @return {Promise}
   * @private
   */
  exports.$requireProfileInfo = function () {
    if (require.specified('profileInfo')) {
      return doRequire('profileInfo');
    }
    return Promise.resolve();
  };

  /**
   * @return {Promise}
   * @private
   */
  exports.$resolveViewInfo = function () {
    return exports.$requireProfileInfo().then(function (profileInfo) {
      if (profileInfo) {
        return profileInfo.getViewInfo();
      }
    });
  };

  /**
   * @param {module:bajaux/Widget} widget
   * @return {Promise}
   */
  function resolveMediaCommands(widget) {
    return Promise.all([exports.resolveCurrentViewItem(), exports.$requireProfileInfo()]).then(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
        item = _ref2[0],
        profileInfo = _ref2[1];
      if (profileInfo && profileInfo.isMediaCommandAvailable() && (item.px || item.moduleName === 'hx' && item.typeName === 'HxPxView')) {
        return doRequire('nmodule/webEditors/rc/wb/profile/media/MediaSettingsWidget').then(function (MediaSettingsWidget) {
          return MediaSettingsWidget.makeCommands(widget.getOrd());
        });
      }
      return [];
    });
  }

  /**
   *
   * @param {baja.Ord} [ord] if the ord is not present, the `getCurrentOrd()` will be used.
   * @return {String}
   */
  function getOrdStrFromParam(ord) {
    if (!ord) {
      ord = exports.getCurrentOrd();
    }
    ord = ord.normalize(); //ensure there is only one view query

    return String(ord);
  }

  /**
   * @param {String} ordStr
   * @return {Number}
   */
  function getViewIndex(ordStr) {
    return ordStr.indexOf('view:');
  }
  return exports;
});

==> Tridium_EMEA_N4_Supervisor-4.14.2.12.zip: rc/wb/profile/profileUtils.js <==
function _toConsumableArray(r) { return _arrayWithoutHoles(r) || _iterableToArray(r) || _unsupportedIterableToArray(r) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _iterableToArray(r) { if ("undefined" != typeof Symbol && null != r[Symbol.iterator] || null != r["@@iterator"]) return Array.from(r); }
function _arrayWithoutHoles(r) { if (Array.isArray(r)) return _arrayLikeToArray(r); }
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
/**
 * @copyright 2019 Tridium, Inc. All Rights Reserved.
 * @author Logan Byam
 */

/* eslint-env browser */

define(['baja!', 'bajaux/commands/UndoManager', 'jquery', 'Promise', 'underscore', 'nmodule/js/rc/asyncUtils/asyncUtils', 'nmodule/webEditors/rc/transform/ExportCommand', 'nmodule/webEditors/rc/wb/commands/SelectionModeCommand', 'nmodule/webEditors/rc/wb/commands/RedoCommand', 'nmodule/webEditors/rc/wb/commands/UndoCommand'], function (baja, UndoManager, $, Promise, _, asyncUtils, ExportCommand, SelectionModeCommand, RedoCommand, UndoCommand) {
  'use strict';

  var doRequire = asyncUtils.doRequire;
  var findWhere = _.findWhere,
    first = _.first,
    isFunction = _.isFunction,
    once = _.once;

  /**
   * API Status: **Private**
   * @exports nmodule/webEditors/rc/wb/profile/profileUtils
   */
  var exports = {};
  var getUndoCommands = once(function () {
    return UndoManager.$installGlobal().then(function (mgr) {
      return [new UndoCommand(mgr), new RedoCommand(mgr)];
    });
  });
  var resolveBrandTitle = once(function () {
    return baja.rpc({
      typeSpec: "workbench:WorkbenchRpc",
      method: "getBrandTitle"
    });
  });

  /**
   * @returns {baja.Ord} the ORD currently being viewed in the profile. This ORD
   * will correspond to the current ORD in Workbench, even if used in the
   * browser (i.e. it may contain `fox:` or similar schemes). Call
   * `.relativizeToSession()` if needed.
   */
  exports.getCurrentOrd = function () {
    return exports.uriToOrd(location.href);
  };

  /**
   * If there is a view query, get the ord without it.
   * @param {baja.Ord} [ord] if the ord is not present, the `getCurrentOrd()` will be used.
   * @returns {baja.Ord} the ORD without the View Query
   */
  exports.getOrdWithoutViewQuery = function (ord) {
    var ordStr = getOrdStrFromParam(ord);
    var viewIndex = getViewIndex(ordStr);
    if (viewIndex > -1) {
      return baja.Ord.make(ordStr.substring(0, viewIndex - 1));
    }
    return baja.Ord.make(ordStr);
  };

  /**
   * @param {string|undefined} uri
   * @param {object} [params]
   * @param {string} [params.host] specify the desired host in the generated
   * ORD. If omitted, will be parsed out of the URI, or omitted if the URI is
   * relative.
   * @param {number} [params.port] specify the desired port in the generated
   * ORD.
   * @param {string} [params.protocol] specify the desired protocol in the
   * generated ORD. If omitted, will be `fox` for an `http` URI, `foxs` for an
   * `https` URI, or omitted if the URI is relative.
   * @returns {baja.Ord} an ORD parsed from the given URI. Will be
   * `baja.Ord.DEFAULT` if the URI did not match the expected format or if the URI is falsy.
   */
  exports.uriToOrd = function (uri) {
    var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    if (!uri) {
      return baja.Ord.DEFAULT;
    }
    var match = uri.match(/^(https?)?(:\/\/)?([^:/]+)?(:(\d+))?(\/ord[/?])(.*)$/);
    if (!match) {
      return baja.Ord.DEFAULT;
    }
    var _match = _slicedToArray(match, 8),
      protocol = _match[1],
      host = _match[3],
      port = _match[5],
      ord = _match[7];
    var path = decodeURIComponent(ord);
    host = params.host || host;
    port = params.port || port;
    if (host) {
      var targetProtocol = params.protocol || (protocol === 'https' ? 'foxs' : 'fox');
      if (port) {
        host = host + ':' + port;
      }
      return baja.Ord.make("ip:".concat(host, "|").concat(targetProtocol, ":|").concat(path));
    } else {
      return baja.Ord.make(path);
    }
  };

  /**
   *
   * @param {module:bajaux/Widget} widget
   * @returns {Promise.<Array.<module:bajaux/commands/Command>>}
   */
  exports.resolveProfileCommands = function (widget) {
    return Promise.all([resolveMediaCommands(widget), getUndoCommands()]).then(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
        mediaCommands = _ref2[0],
        undoCommands = _ref2[1];
      return [].concat(_toConsumableArray(mediaCommands), _toConsumableArray(undoCommands), [new SelectionModeCommand(), new ExportCommand(widget)]);
    });
  };

  /**
   * Resolve to the current View item if it is available.
   * @return {Promise.<module:profileInfo~ViewInfo|undefined>}
   */
  exports.resolveCurrentViewItem = function () {
    return exports.$resolveViewInfo().then(function (viewInfo) {
      if (viewInfo) {
        var list = viewInfo.list;
        return findWhere(list, {
          def: true
        }) || first(list);
      }
    });
  };

  /**
   * Return the current ViewId. This information is available from `hx`
   * even if the 'profileInfo' is not defined.
   * @return {Promise.<String|undefined>}
   */
  exports.resolveCurrentViewId = function () {
    return exports.resolveCurrentViewItem().then(function (viewItem) {
      if (viewItem) {
        var viewQuery = exports.getViewQuery(baja.Ord.make(viewItem.ord));
        if (viewQuery) {
          return viewQuery.getViewId();
        }
      }
      var hx = window.hx;
      if (hx && isFunction(hx.getProfileInfo)) {
        var profileInfo = hx.getProfileInfo();
        return profileInfo && profileInfo.viewId;
      }
    });
  };

  /**
   * Resolve the Brand Title. This should not so the answer is cached.
   *
   * @return {Promise.<String>}
   */
  exports.resolveBrandTitle = function () {
    return resolveBrandTitle();
  };

  /**
   * Get the ViewQuery for an ord.
   * @param {baja.Ord} [ord] if the ord is not present, the `getCurrentOrd()` will be used.
   * @return {baja.ViewQuery|undefined}
   */
  exports.getViewQuery = function (ord) {
    var ordStr = getOrdStrFromParam(ord),
      viewIndex = getViewIndex(ordStr);
    if (viewIndex > -1) {
      var viewQueryBody = ordStr.substring(viewIndex + 5);
      return new baja.ViewQuery(viewQueryBody);
    }
  };

  /**
   * If the given URI is not compatible with the current state of the web
   * profile, then it must be loaded with a full page refresh so that the
   * profile chrome can be updated. This typically happens when the fullScreen
   * query parameter is changing.
   *
   * @param {string} uri
   * @returns {boolean} true if the given URI must be loaded with a full page
   * refresh.
   */
  exports.requiresRefresh = function (uri) {
    var currentOrd = exports.getCurrentOrd();
    var newOrd = exports.uriToOrd(uri);
    return hasFullScreen(currentOrd) !== hasFullScreen(newOrd);
  };
  function hasFullScreen(ord) {
    var viewQuery = exports.getViewQuery(ord);
    if (!viewQuery) {
      return false;
    }
    return String(viewQuery.getParameters().fullScreen).toLowerCase() === 'true';
  }

  /**
   * Get a View Parameter from the current `window.location.href`
   * @param {String} name
   * @return {String|undefined}
   */
  exports.getViewParameter = function (name) {
    var viewQuery = exports.getViewQuery();
    if (viewQuery) {
      var params = viewQuery.getParameters();
      return params[name];
    }
  };

  /**
   * Get the custom message provided by jetty from JQuery error handler
   * @param {JQuery.jqXHR} jqXHR
   * @param {String} textStatus
   * @param {Error} errorThrown
   * @return {Error}
   */
  exports.getServletError = function (jqXHR, textStatus, errorThrown) {
    var responseText = jqXHR.responseText;
    //jetty provides HTML to get to local error message so we must generate an HTML page and parse it from there.
    var message = $(responseText).find('tr:nth-child(3) td').text();
    if (!message && errorThrown) {
      message = String(errorThrown);
    }
    if (!message) {
      message = textStatus;
    }
    return new Error(message);
  };

  /**
   * Get the browser's `window.location.href`.
   * @private
   * @return {String}
   */
  exports.$getLocation = function () {
    return window.location.href;
  };

  /**
   * If `profileInfo` is not defined, this will resolve to an `undefined` value,
   * This will happen for profile's other than the Html5HxProfile and it will
   * happen within the Html5HxProfile when the page was loaded as a popup.
   * @return {Promise}
   * @private
   */
  exports.$requireProfileInfo = function () {
    if (require.specified('profileInfo')) {
      return doRequire('profileInfo');
    }
    return Promise.resolve();
  };

  /**
   * @return {Promise}
   * @private
   */
  exports.$resolveViewInfo = function () {
    return exports.$requireProfileInfo().then(function (profileInfo) {
      if (profileInfo) {
        return profileInfo.getViewInfo();
      }
    });
  };

  /**
   * @param {module:bajaux/Widget} widget
   * @return {Promise}
   */
  function resolveMediaCommands(widget) {
    return Promise.all([exports.resolveCurrentViewItem(), exports.$requireProfileInfo()]).then(function (_ref3) {
      var _ref4 = _slicedToArray(_ref3, 2),
        item = _ref4[0],
        profileInfo = _ref4[1];
      if (profileInfo && profileInfo.isMediaCommandAvailable() && (item.px || item.moduleName === 'hx' && item.typeName === 'HxPxView')) {
        return doRequire('nmodule/webEditors/rc/wb/profile/media/MediaSettingsWidget').then(function (MediaSettingsWidget) {
          return MediaSettingsWidget.makeCommands(widget.getOrd());
        });
      }
      return [];
    });
  }

  /**
   *
   * @param {baja.Ord} [ord] if the ord is not present, the `getCurrentOrd()` will be used.
   * @return {String}
   */
  function getOrdStrFromParam(ord) {
    if (!ord) {
      ord = exports.getCurrentOrd();
    }
    ord = ord.normalize(); //ensure there is only one view query

    return String(ord);
  }

  /**
   * @param {String} ordStr
   * @return {Number}
   */
  function getViewIndex(ordStr) {
    return ordStr.indexOf('view:');
  }
  return exports;
});
